window.Gleam.initSearch([{"doc":"aws4_request","title":"aws4_request","content":"# aws4_request\n\nAn AWS Signature Version 4 client implementation, useful for making\nauthenticated requests to services such as AWS S3.\n\n[![Package Version](https://img.shields.io/hexpm/v/aws4_request)](https://hex.pm/packages/aws4_request)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/aws4_request/)\n![Erlang-compatible](https://img.shields.io/badge/target-erlang-a2003e)\n![JavaScript-compatible](https://img.shields.io/badge/target-javascript-f1e05a)\n\n```sh\ngleam add aws4_request\n```\n\n```gleam\nimport gleam/httpc\nimport aws4_request\nimport gleam/http/request\n\npub fn main() {\n  let assert Ok(request) =\n    request.to(&quot;https://iam.amazonaws.com/?Action=ListUsers&amp;Version=2010-05-08&quot;)\n  let request =\n    request\n    |&gt; request.set_header(\n      &quot;content-type&quot;,\n      &quot;application/x-www-form-urlencoded; charset=utf-8&quot;,\n    )\n    |&gt; request.set_method(http.Get)\n    |&gt; request.set_body(&lt;&lt;&gt;&gt;)\n\n  let signed_request =\n    aws4_request.signer(\n      access_key_id: &quot;AKIDEXAMPLE&quot;,\n      secret_access_key: &quot;wJalrXUtnFEMI/K7MDENG+bPxRfiCYEXAMPLEKEY&quot;,\n      region: &quot;us-east-1&quot;,\n      service: &quot;iam&quot;,\n    )\n    |&gt; aws4_request.sign_bits(request)\n\n  // Now send the signed request with a HTTP client\n  httpc.send_bit(signed_request)\n}\n```\n\nFurther documentation can be found at &lt;https://hexdocs.pm/aws4_request&gt;.\n","url":"index.html"},{"doc":"aws4_request","title":"Signer","content":"pub type Signer {\n  Signer(\n    date_time: Option(DateTime),\n    access_key_id: String,\n    secret_access_key: String,\n    region: String,\n    service: String,\n    session_token: Option(String),\n  )\n}\n\nSigner(\n  date_time: Option(DateTime),\n  access_key_id: String,\n  secret_access_key: String,\n  region: String,\n  service: String,\n  session_token: Option(String),\n)\n\n\nSynonyms:\naws4_request.Signer\naws4_request Signer","url":"aws4_request.html#Signer"},{"doc":"aws4_request","title":"sign_bits","content":"pub fn sign_bits(\n  signer signer: Signer,\n  request request: Request(BitArray),\n) -&gt; Request(BitArray)\n Sign a request that has a bit array body.\n\nSynonyms:\naws4_request.sign_bits\naws4_request sign_bits","url":"aws4_request.html#sign_bits"},{"doc":"aws4_request","title":"sign_string","content":"pub fn sign_string(\n  signer signer: Signer,\n  request request: Request(String),\n) -&gt; Request(BitArray)\n Sign a request that has a string body.\n\nSynonyms:\naws4_request.sign_string\naws4_request sign_string","url":"aws4_request.html#sign_string"},{"doc":"aws4_request","title":"signer","content":"pub fn signer(\n  access_key_id access_key_id: String,\n  secret_access_key secret_access_key: String,\n  region region: String,\n  service service: String,\n) -&gt; Signer\n Create a new request signer for the given credentials, service, and region.\n\nSynonyms:\naws4_request.signer\naws4_request signer","url":"aws4_request.html#signer"},{"doc":"aws4_request","title":"with_date_time","content":"pub fn with_date_time(\n  signer: Signer,\n  date_time: #(#(Int, Int, Int), #(Int, Int, Int)),\n) -&gt; Signer\n Set a specific time to use for request signing, overriding the default\n behaviour of using the current time.\n\nSynonyms:\naws4_request.with_date_time\naws4_request with_date_time","url":"aws4_request.html#with_date_time"},{"doc":"aws4_request","title":"with_region","content":"pub fn with_region(signer: Signer, region: String) -&gt; Signer\n\nSynonyms:\naws4_request.with_region\naws4_request with_region","url":"aws4_request.html#with_region"},{"doc":"aws4_request","title":"with_service","content":"pub fn with_service(signer: Signer, service: String) -&gt; Signer\n\nSynonyms:\naws4_request.with_service\naws4_request with_service","url":"aws4_request.html#with_service"},{"doc":"aws4_request","title":"with_session_token","content":"pub fn with_session_token(\n  signer: Signer,\n  session_token: String,\n) -&gt; Signer\n Set a session token when using temporary security credentials.\n This sets the `x-amz-security-token` header.\n\nSynonyms:\naws4_request.with_session_token\naws4_request with_session_token","url":"aws4_request.html#with_session_token"},{"doc":"aws4_request","title":"aws4_request","content":"","url":"aws4_request.html"}]);